@@ -46,17 +46,8 @@ class BaseHandler(RequestHandler):
             handler_method = res[0][1]
             # 最终整理后的请求参数集合
             params_list = []
-            # 获取当前请求的Content-Type
-            content_type = self.request.headers.get('Content-Type')
             # 当前请求参数
             arguments = self.request.arguments
-            # 如果当前请求contentType为application/json 需要对request.body进行JSON字符串转换
-            body_arguments = self.request.body
-            if body_arguments:
-                # 获取body 对象并把byte转为str
-                body_arguments = body_arguments.decode()
-                # 将json字符串转换为json对象 并加入到 请求参数字典中
-                arguments.update(json.loads(body_arguments))
             # 获取处理方法的 参数签名
             signature = inspect.signature(handler_method)
             # parameterName 参数名称, parameter 参数对象
@@ -136,14 +127,12 @@ class BaseHandler(RequestHandler):
             content_type = self.request.headers.get('Content-Type')
             # 当前请求参数
             arguments = self.request.arguments
-            # 如果当前请求contentType为application/json 需要对request.body进行JSON字符串转换
-            if content_type == 'application/json':
-                body_arguments = self.request.body
-                if body_arguments:
-                    # 获取body 对象并把byte转为str
-                    body_arguments = body_arguments.decode()
-                    # 将json字符串转换为json对象 并加入到 请求参数字典中
-                    arguments.update(json.loads(body_arguments))
+            body_arguments = self.request.body
+            if body_arguments:
+                # 获取body 对象并把byte转为str
+                body_arguments = body_arguments.decode()
+                # 将json字符串转换为json对象 并加入到 请求参数字典中
+                arguments.update(json.loads(body_arguments))
             # 获取处理方法的 参数签名
             signature = inspect.signature(handler_method)
             # parameterName 参数名称, parameter 参数对象
